@@ -12,8 +12,8 @@ TAKER_ACCOUNT_OWNER = '0xf809e07870dca762B9536d61A4fBEF1a17178092'
 CANONICAL_ORDERS_ADDRESS = '0xCd81398895bEa7AD9EFF273aeFFc41A9d83B4dAD'
 SOLO_MARGIN_ADDRESS = '0x1E0447b19BB6EcFdAe1e4AE1694b0C3659614e4e'
 PAYABLE_PROXY_ADDRESS = '0xa8b39829cE2246f89B31C013b8Cde15506Fb9A76'
-P1_ORDERS_ADDRESS = '0x6779c1C4033ffD75a563CfB1BbC86C12D732591f'
-PERPETUAL_ADDRESS = '0xD029c869dEc40A3a53a3799A1181306B0f747AdD'
+P1_ORDERS_ADDRESS = '0x3ea6F88eC8F7b24Bb3Ad206fa80124210e8e28F3'
+PERPETUAL_ADDRESS = '0x07aBe965500A49370D331eCD613c7AC47dD6e547'
 WETH_ADDRESS = '0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2'
 SAI_ADDRESS = '0x89d24A6b4CcB1B6fAA2625fE562bDD9a23260359'
 USDC_ADDRESS = '0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48'
@@ -53,9 +53,9 @@ SIDE_SELL = 'SELL'
 
 # ------------ Fees ------------
 FROM_BIPS = Decimal('1e-4')
-SMALL_TRADE_SIZE_WETH = 0.5 * (10 ** DECIMALS_WETH)
-SMALL_TRADE_SIZE_DAI = 100 * (10 ** DECIMALS_DAI)
-SMALL_TRADE_SIZE_PBTC = 0.01 * (10 ** DECIMALS_PBTC)
+SMALL_TRADE_SIZE_WETH = 5 * (10 ** DECIMALS_WETH)
+SMALL_TRADE_SIZE_DAI = 1000 * (10 ** DECIMALS_DAI)
+SMALL_TRADE_SIZE_PBTC = 0.1 * (10 ** DECIMALS_PBTC)
 FEE_SMALL_WETH = Decimal(50) * FROM_BIPS
 FEE_LARGE_WETH = Decimal(15) * FROM_BIPS
 FEE_SMALL_DAI = Decimal(50) * FROM_BIPS
@@ -77,3 +77,7 @@ PRICE_ORACLE_USD_MULTIPLIER = 10 ** 36
 
 # ------------ Math ------------
 BASE_DECIMAL = Decimal(10 ** 18)
+
+# ------------ Account Numbers ------------
+ACCOUNT_NUMBERS_SPOT = 78249916358380492593314239409032173911741268194868200833150293576330928686520  # NOQA
+ACCOUNT_NUMBERS_MARGIN = 0
